/**
    Character Driver for Beckhoff BIOS API
    Author: Patrick Brünn <p.bruenn@beckhoff.com>
    Author: Chris Johns <chrisj@rtems.org>
    Copyright (C) 2013 - 2015  Beckhoff Automation GmbH

    Redistribution and use in source and binary forms, with or without
    modification, are permitted provided that the following conditions
    are met:
    1. Redistributions of source code must retain the above copyright
       notice, this list of conditions and the following disclaimer.
    2. Redistributions in binary form must reproduce the above copyright
     notice, this list of conditions and the following disclaimer in the
     documentation and/or other materials provided with the distribution.

    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
    A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
    OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
    SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
    LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
    DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
    THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
    (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
    OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

#ifndef __BBAPI_API_H_
#define __BBAPI_API_H_

#include <pthread.h>

#define BBIOSAPI_SIGNATURE_PHYS_START_ADDR 0xFFF00000	// Defining the Physical start address for the search
#define BBIOSAPI_SIGNATURE_SEARCH_AREA     0x000FFFFF	// Defining the Memory search area size
#define BBAPI_BUFFER_SIZE 256	// maximum size of a buffer shared between user and kernel space

/**
 * struct bbapi_object - manage access to Beckhoff BIOS functions
 * @memory: pointer to a BIOS copy in RAM
 * @entry: function pointer to the BIOS API function in RAM
 * @in: buffer to exchange data between user space and BIOS
 * @out: buffer to exchange data between BIOS and user space
 * @dev: meta data for the character device interface
 *
 * The size of the output buffer should be large enough to satisfy the
 * largest BIOS command. Right now this is: BIOSIOFFS_UEEPROM_READ.
 */
struct bbapi_object {
	void *memory;
	void *entry;
	char in[BBAPI_BUFFER_SIZE];
	char out[BBAPI_BUFFER_SIZE];
	pthread_mutex_t mutex;
};

extern unsigned int bbapi_read(uint32_t group, uint32_t offset,
			       void * out, uint32_t size);

extern unsigned int bbapi_write(uint32_t group, uint32_t offset,
				void * in, uint32_t size);

extern int bbapi_board_is(const char *boardname);
#endif /* #ifndef __BBAPI_API_H_ */
