/*
 * Copyright (c) 2016 Chris Johns <chrisj@rtems.org>.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

/*
 * DB Server for RTEMS.
 */

#ifndef _RTEMS_DBSERVER_h
#define _RTEMS_DBSERVER_h

#include <stdbool.h>

#include <rtems.h>
#include <rtems/printer.h>

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

/**
 * DB default server port. 'RT' as ASCII.
 */
#define RTEMS_DB_PORT_DEFAULT (8284)

/**
 * Timeout period for an ack
 */
#define RTEMS_DBSERVER_TIMEOUT (3)

/**
 * Start the DB server.
 */
extern int rtems_dbserver_start(int                  port,
                                int                  timeout,
                                rtems_task_priority  priority,
                                const rtems_printer* printer);

/**
 * Stop the DB server.
 */
extern int rtems_dbserver_stop(void);

/**
 * Is the DB server running?.
 */
extern bool rtems_dbserver_running(void);

/**
 * Control remote debug printing.
 */
extern int rtems_dbserver_remote_debug(bool state);

#ifdef __cplusplus
}
#endif /* __cplusplus */


#endif
